function format_axes(aspect_ratio)
% FORMAT_AXES formats FIGURE AXES plotted by MATLAB.
% Argument 'aspect_ratio' is a 1x2 array
% to indicate width and height of the plotted figure. 
% Created on 10/11/2023, Jingfeng Zhou @ CIBR

    if nargin == 0 || isempty(aspect_ratio)
        aspect_ratio = [1,1];
    end

    axes_handle = gca; box off;
    
    % adjust tick size, depending on if current axis is squared
    box_aspect = get(axes_handle,'PlotBoxAspectRatio');
    if box_aspect(1) == box_aspect(2)
        tick_size = min(0.026/aspect_ratio(1),0.026/aspect_ratio(2));
    else
        tick_size = min(0.02/aspect_ratio(1),0.02/aspect_ratio(2));
    end
    
    % figure size adjusted by aspect ratio
    W = 340; H = 210;
    fig_width = W * aspect_ratio(1);
    fig_height = H * aspect_ratio(2);
    
    % adjust figure and axis appearance
    set(gcf,'unit','pixels','position',[100,100,fig_width,fig_height]);
    set(axes_handle,'Position',[0.36,0.26,0.52,0.65]);
    set(axes_handle,'LineWidth',0.75,'FontSize',10,'TickLength',[tick_size,tick_size],'tickdir','out');
    set(axes_handle,'FontName', 'Arial');
    set(findall(axes_handle,'Type','Text'),'FontWeight', 'Normal');

    % adjust xlabel and ylabel distances from axes
    current_XPosition = axes_handle.XLabel.Position;
    current_YPosition = axes_handle.YLabel.Position;
    if strcmp(get(axes_handle,'YDir'),'normal')
        current_XPosition(2) = axes_handle.YLim(1) - (axes_handle.YLim(2) - axes_handle.YLim(1)) * 0.15/aspect_ratio(2);
    elseif strcmp(get(axes_handle,'YDir'),'reverse')
        current_XPosition(2) = axes_handle.YLim(2) + (axes_handle.YLim(2) - axes_handle.YLim(1)) * 0.15/aspect_ratio(2);
    end
    current_YPosition(1) = axes_handle.XLim(1) - (axes_handle.XLim(1) - current_YPosition(1)) * 0.85;
    axes_handle.XLabel.Position = current_XPosition;
    axes_handle.YLabel.Position = current_YPosition;

    % adjust ticklabels away from axes
    axes_handle.XRuler.TickLabelGapOffset = -1;
    axes_handle.YRuler.TickLabelGapOffset = 0;

end

